@@ -33,7 +33,7 @@ class server:
         client.close()
         return code
     def regions():
-        return "SMTP regions: de, uk, us, it, es, tw, cn, ar, au, fr, ca, in, hk, th, sg, vn, ua, ru, tr, zn"
+        return "SMTP regions: tr, ru, ua, us, uk, de, fr, it"
     def debug(type:str):
         global debug
         if type == "on":
